@@ -32,6 +32,42 @@
 #include <libgnomevfs/gnome-vfs-async-ops.h>
 #include <sys/types.h>
 
+#define TEXT_BUG_CRASH "Description of the crash:\n\n\n\
+Steps to reproduce the crash:\n\
+1. \n\
+2. \n\
+3. \n\n\
+Expected Results:\n\n\n\
+How often does this happen?\n\n\n\
+Additional Information:\n"
+
+#define TEXT_BUG_WRONG "Description of Problem:\n\n\n\
+Steps to reproduce the problem:\n\
+1. \n\
+2. \n\
+3. \n\n\
+Actual Results:\n\n\n\
+Expected Results:\n\n\n\
+How often does this happen?\n\n\n\
+Additional Information:\n"
+
+
+#define TEXT_BUG_I18N "Language:\n\n\
+Wrong text location:\n\
+Current text:\n\n\n\
+Expected text:\n\n\n\
+Additional Information:\n"
+
+
+#define TEXT_BUG_DOC "Language:\n\n\
+Documentation chapter/section:\n\
+Current text:\n\n\n\
+Expected text:\n\n\n\
+Additional Information:\n"
+
+#define TEXT_BUG_REQUEST "Please describe your feature request:\n\n"
+
+
 typedef enum {
 	CRASH_DIALOG,
 	CRASH_CORE,
@@ -46,6 +82,7 @@ typedef enum {
 } SubmitType;
 
 typedef enum {
+	STATE_INTRO,
 	STATE_GDB,
 	STATE_PRODUCT,
 	STATE_COMPONENT,
@@ -57,6 +94,17 @@ typedef enum {
 	STATE_LAST
 } BuddyState;
 
+typedef enum {
+	BUG_CRASH,
+	BUG_DEBUG,
+	BUG_WRONG,
+	BUG_I18N,
+	BUG_DOC,
+	BUG_REQUEST
+} BugType;
+
+
+
 typedef struct {
 	/* contact page */
 	gchar *name;
@@ -81,9 +129,12 @@ extern PoptData popt_data;
 typedef struct {
 	GladeXML  *xml;
 	BuddyState state;
+	BugType bug_type;
 	gboolean	product_skipped;
 	gboolean	component_skipped;
 	gboolean	mostfreq_skipped;
+	gboolean	description_filled;
+	gboolean	show_products;
 
 	/* canvas stuff */
 	GnomeCanvasItem *title_box;
@@ -98,8 +149,6 @@ typedef struct {
 	GdkPixbuf *throbber_pb;
 	guint            throbber_id;
 
-	gboolean already_run;
-
 	char              *bts_file;
 
 	CrashType  crash_type;
@@ -107,6 +156,9 @@ typedef struct {
 	int selected_row;
 	int progress_timeout;
 
+
+	char      *distro;
+	
 	/* gdb stuff */
 	pid_t       app_pid;
 	pid_t       gdb_pid;
@@ -129,6 +181,7 @@ typedef struct {
 	BugzillaProduct   *product;
 	BugzillaComponent *component;
 	char              *severity;
+	char		  *version;
 
 	GList *dlsources;
 	GList *dldests;
@@ -145,11 +198,10 @@ typedef struct {
 	const char *gnome_version;
 
 	char *gnome_platform_version;
-	char *gnome_vendor;
+	char *gnome_distributor;
 
 	guint dl_timeout;
 
-	gboolean show_products;
 } DruidData;
 
 extern DruidData druid_data;
@@ -169,9 +221,6 @@ void stop_progress (void);
 
 void append_packages (void);
 
-void load_config (void);
-void save_config (void);
-
 #define GET_WIDGET(name) (get_widget ((name), (G_STRLOC)))
 
 GtkWidget *get_widget (const char *s, const char *loc);
