@@ -175,6 +175,7 @@ load_products_xml (BugzillaBTS *bts, xmlDoc *doc)
 	BugzillaProduct *prod;
 	BugzillaComponent *comp;
 	xmlNode *node, *cur;
+	xmlChar *tmp;
 
 	d(g_print ("products:\n"));
 
@@ -184,6 +185,16 @@ load_products_xml (BugzillaBTS *bts, xmlDoc *doc)
 	for (node = xmlDocGetRootElement (doc)->children; node; node = node->next) {
 		d(g_print ("\t%s\n", node->name));
 		if (!strcmp (node->name, "product")) {
+
+			tmp = xmlGetProp (node, "disallownew");
+			if (tmp && !strcmp(tmp, "1")) {
+				xmlFree (tmp);
+				continue;
+			}
+			if (tmp) {
+				xmlFree(tmp);
+			}
+
 			prod = g_new0 (BugzillaProduct, 1);
 			prod->bts = bts;
 
@@ -197,15 +208,17 @@ load_products_xml (BugzillaBTS *bts, xmlDoc *doc)
 			for (cur = node->children; cur; cur = cur->next) {
 				d(g_print ("\t\t%s\n", node->name));
 				if (!strcmp (cur->name, "component")) {
-					comp = g_new0 (BugzillaComponent, 1);
-					comp->product = prod;
-					
 					/* This is a workaround for bad generated products.xml
 					   We really need to strict validation on bugzilla side
 					   or rewrote the script generating products.xml*/
-					if (!xmlGetProp (cur, "value"))
+					tmp = xmlGetProp (cur, "value");
+					if (!tmp) {
 						continue;
-	
+					} 
+					xmlFree (tmp);
+					comp = g_new0 (BugzillaComponent, 1);
+					comp->product = prod;
+					
 					comp->name        = XML_NODE_GET_PROP (cur, "value");
 					comp->description = XML_NODE_GET_PROP (cur, "description");
 
@@ -354,6 +367,7 @@ get_xml_file (BugzillaBTS *bts, const char *key, char md5[33], XMLFunc parse_fun
 	xmlfile->tmp_path    = g_build_filename (tmppath,       "bugzilla", bts->subdir, tmp_key, NULL);
 	localdir             = g_build_filename (tmppath,       "bugzilla", bts->subdir, NULL);
 
+	g_free (tmp_key);
 	g_free (tmppath);
 	
 	if (e_mkdir_hier (localdir, S_IRWXU)) {
@@ -362,12 +376,16 @@ get_xml_file (BugzillaBTS *bts, const char *key, char md5[33], XMLFunc parse_fun
 	
 	g_free (localdir);
 
-	if (!bts->md5s_downloaded || !md5 || md5=="")
+	if (!bts->md5s_downloaded || !md5 || md5=="") {
+		g_free (src_uri);
 		return xmlfile;
+	}
 
 	md5_get_digest_from_file (xmlfile->cache_path, digest);
-	if (md5str_equal_digest(md5, digest))
+	if (md5str_equal_digest(md5, digest)) {
+		g_free (src_uri);
 		return xmlfile;
+	}
 		
 	xmlfile->source_uri = gnome_vfs_uri_new (src_uri);
 	g_free (src_uri);
@@ -517,13 +535,8 @@ load_bugzilla (const char *filename)
 	bts->severity_node   = gnome_config_get_string ("severity_node=severities");
 	bts->severity_item   = gnome_config_get_string ("severity_item=severity");
 	bts->severity_header = gnome_config_get_string ("severity_header=Severity");
-	if ((time (NULL) - druid_data.last_update_check) > CHECK_UPDATES_TIME ) {
-		s = gnome_config_get_string ("md5sums");
-		if (s && s!=NULL) {
-			bugzilla_get_md5sums (bts, s);
-			g_free (s);
-		}
-	}
+	if ((time (NULL) - druid_data.last_update_check) > CHECK_UPDATES_TIME )
+		bugzilla_get_md5sums (bts, gnome_config_get_string ("md5sums"));
 	
 	bts->products_xml = get_xml_file (bts, "products", 
 					  bts->products_xml_md5,
@@ -1096,6 +1109,11 @@ load_applets (GnomeIconTheme *git)
 
 	for (i = 0; i < info_list->_length; i++) {
 		info = info_list->_buffer + i;
+		if (!bonobo_server_info_prop_lookup (info,
+						     BA_BUGZILLA_BUGZILLA,
+NULL)) {
+			continue;
+		}
 
 		bugzilla_application_new (
 			bonobo_server_info_prop_lookup (info, "name", langs),
@@ -1147,7 +1165,7 @@ visit_cb (const char *rel_path,
 		goto visit_cb_out;
 	}
     
-	if (gnome_desktop_item_get_entry_type (ditem) != GNOME_DESKTOP_ITEM_TYPE_APPLICATION)
+	if ((gnome_desktop_item_get_entry_type (ditem) != GNOME_DESKTOP_ITEM_TYPE_APPLICATION) || !gnome_desktop_item_get_string (ditem, BUGZILLA_BUGZILLA))
 		goto visit_cb_out;
 
 	icon = gnome_desktop_item_get_icon (ditem, git);
@@ -1467,10 +1485,6 @@ generate_email_text (gboolean include_headers)
 	GString *email;
 	char *subject, *body, *s, *debug_info, *version, *severity;
 
-	gboolean is_bugzilla;
-       
-	is_bugzilla = !(GTK_TOGGLE_BUTTON (GET_WIDGET ("no-product-toggle"))->active || druid_data.product == NULL);
-
 	email = g_string_new (NULL);
 
 	subject    = buddy_get_text ("desc-subject");
@@ -1492,11 +1506,7 @@ generate_email_text (gboolean include_headers)
 	get_distro_name();
 	if (druid_data.distro)
 		g_string_append_printf (email, "Distribution: %s\n", druid_data.distro);
-	if (!is_bugzilla) {
-		g_string_append (email, "(This bug report was generated by Bug Buddy " VERSION ")\n");
-		g_string_append (email, "Description:\n");
-		
-	} else if (druid_data.product->bts->submit_type == BUGZILLA_SUBMIT_DEBIAN) {
+	if (druid_data.product->bts->submit_type == BUGZILLA_SUBMIT_DEBIAN) {
 		/* This is what gnome.org and ximian.com use */
 		g_string_append_printf (email, "Package: %s\n", druid_data.product->name);
 		g_string_append_printf (email, "%s: %s\n", druid_data.product->bts->severity_header, severity);					
