@@ -158,12 +158,21 @@ on_druid_about_clicked (GtkWidget *button, gpointer data)
 		NULL
 	};
 
+	static const char *translators;
+
+	/* Translators should localize the following string
+         * which will give them credit in the About box.
+         * E.g. "Fulano de Tal <fulano@detal.com>"
+         */
+        translators = _("translator_credits-PLEASE_ADD_YOURSELF_HERE");
+
 	if (about) {
 		gtk_window_present (GTK_WINDOW (about));
 		return;
 	}
 		
-	pixbuf = gdk_pixbuf_new_from_file(BUDDY_ICONDIR "/bug-buddy.png", NULL);
+	pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+					   "bug-buddy", 48, 0, NULL);
 	
 	about = gnome_about_new (_("Bug Buddy"), VERSION,
 				 "Copyright \xc2\xa9 1999-2002 Jacob Berkman\n"
@@ -172,7 +181,8 @@ on_druid_about_clicked (GtkWidget *button, gpointer data)
 				 _("The graphical bug reporting tool for GNOME."),
 				 authors,
 				 documentors,
-				 NULL, pixbuf);
+				 (strcmp (translators, "translator_credits-PLEASE_ADD_YOURSELF_HERE")
+					 ? translators : NULL), pixbuf);
 
 	if (pixbuf != NULL)
 		gdk_pixbuf_unref (pixbuf);
@@ -301,8 +311,7 @@ on_druid_prev_clicked (GtkWidget *w, gpointer data)
 			newstate = STATE_MOSTFREQ;
 			break;
 		}
-		if (!druid_data.component_skipped && 
-		    !GTK_TOGGLE_BUTTON (GET_WIDGET ("no-product-toggle"))->active) {
+		if (!druid_data.component_skipped) {
 			newstate = STATE_COMPONENT;
 			break;
 		}
@@ -961,30 +970,6 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 		BugzillaProduct *product = NULL;
 		BugzillaApplication *application = NULL;
 		/* check that the package is ok */
-		if (GTK_TOGGLE_BUTTON (GET_WIDGET ("no-product-toggle"))->active) {
-			static gboolean dialog_shown = FALSE;
-			if (!dialog_shown) {
-				d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-							    0,
-							    GTK_MESSAGE_WARNING,
-							    GTK_BUTTONS_OK,
-							    _("Since Bug Buddy doesn't know about the product "
-							      "you wish to submit a bug report in, you will have "
-							      "to manually address the bug report."));
-				gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_OK);
-				gtk_dialog_run (GTK_DIALOG (d));
-				gtk_widget_destroy (d);
-				dialog_shown = TRUE;
-			}
-			buddy_set_text ("email-to-entry", "");
-			druid_data.product = NULL;
-			druid_data.component = NULL;
-			newstate = STATE_DESC;
-			druid_data.component_skipped = TRUE;
-			druid_data.mostfreq_skipped = TRUE;
-			break;
-		}
- 
 		if (druid_data.show_products) {
 			product = get_selected_row ("product-list", PRODUCT_DATA);
  			if (!product) {
@@ -998,7 +983,14 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 				gtk_dialog_run (GTK_DIALOG (d));
 				gtk_widget_destroy (d);
 				return;
+			} else {
+				gchar *text;
+				text = g_strdup_printf (_("Please choose a component, version, and severity level for product %s"), product->name);
+				
+				buddy_set_text ("component-label", text);
+				g_free (text);
 			}
+				
 		} else {
 			application = get_selected_row ("product-list", PRODUCT_DATA);
  			if (!application) {
@@ -1012,7 +1004,14 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 				gtk_dialog_run (GTK_DIALOG (d));
 				gtk_widget_destroy (d);
 				return;
+			} else {
+				gchar *text;
+				text = g_strdup_printf (_("Please choose a component, version, and severity level for application %s"), application->name);
+
+				buddy_set_text ("component-label", text);
+				g_free (text);
 			}
+
 			if (application->bugzilla && application->product) {
 				BugzillaBTS *bts = g_hash_table_lookup (druid_data.bugzillas, application->bugzilla);
 				if (bts) {
@@ -1020,28 +1019,16 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 				}
 			}
 			if (!product) {
-				if (!application->email) {
-					d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-								    0,
-								    GTK_MESSAGE_WARNING,
-								    GTK_BUTTONS_OK,
-								    _("This application has not included information about "
-								      "how to submit bugs.\n\n"
-								      "If you know an email address where bug reports should be sent, "
-								      "you will be able to specify that later.\n\n"
-								      "You may be able to find one in an \"About\" box in the "
-								      "application, or in the application's documentation."));
-					gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_OK);
-					gtk_dialog_run (GTK_DIALOG (d));
-					gtk_widget_destroy (d);
-				}
-				buddy_set_text ("email-to-entry", application->email);
-				druid_data.product = NULL;
-				druid_data.component = NULL;
-				newstate = STATE_DESC;
-				druid_data.component_skipped = TRUE;
-				druid_data.mostfreq_skipped = TRUE;
-				break;
+				d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
+							    0,
+							    GTK_MESSAGE_ERROR,
+							    GTK_BUTTONS_OK,
+							    _("This Application has bug information, but Bug Buddy doesn't know about it. Please choose another application."));
+				gtk_dialog_set_default_response (GTK_DIALOG (d),
+								 GTK_RESPONSE_OK);
+				gtk_dialog_run (GTK_DIALOG (d));
+				gtk_widget_destroy (d);
+				return;
 			}
 				
 		}
@@ -1139,6 +1126,5 @@ on_druid_cancel_clicked (GtkWidget *w, gpointer data)
 	gtk_widget_destroy (d);
 
 	stop_gdb ();
-	save_config ();
 	gtk_main_quit ();
 }
